NeuroImaging workflows (NIworkflows): robust processing tools for MRI data
==========================================================================

These pipelines are developed by the `Poldrack lab at Stanford University <https://poldracklab.stanford.edu/>`_
for use at the `Center for Reproducible Neuroscience <http://reproducibility.stanford.edu/>`_,
as well as for open-source software distribution.

.. image:: https://circleci.com/gh/poldracklab/nipype-workflows/tree/master.svg?style=shield
  :target: https://circleci.com/gh/poldracklab/nipype-workflows/tree/master
  
.. image:: https://readthedocs.org/projects/nipype-workflows/badge/?version=latest
  :target: http://nipype-workflows.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

Reporting Issues
----------------

All bugs, concerns and enhancement requests for this software can be submitted here:

https://github.com/poldracklab/nipype-workflows/issues.


Authors
-------

The authors of NIworkflows can be found `here <AUTHORS>`_.

License
-------

Preprocessing-workflow is licensed under the Revised BSD Licence. The license can be found `here <LICENSE>`_.